/*
 * Copyright (C) 2014 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.futo.inputmethod.keyboard.internal;

import android.util.Log;

import java.util.HashMap;
import java.util.Locale;

/**
 * !!!!! DO NOT EDIT THIS FILE !!!!!
 *
 * This file is generated by tools/make-keyboard-text-py.
 * To update some texts, please update the *.json files located at
 *   tools/make-keyboard-text-py/locales
 * and then cd into the make-keyboard-text-py directory and run src/generate.py
 */
public final class KeyboardTextsTable {
    // Name to index map.
    private static final HashMap<String, Integer> sNameToIndexesMap = new HashMap<>();
    // Locale to texts table map.
    private static final HashMap<String, String[]> sLocaleToTextsTableMap = new HashMap<>();
    // TODO: Remove this variable after debugging.
    // Texts table to locale maps.
    private static final HashMap<String[], String> sTextsTableToLocaleMap = new HashMap<>();

    public static String getText(final String name, final String[] textsTable) {
        final Integer indexObj = sNameToIndexesMap.get(name);
        if (indexObj == null) {
            if(name.startsWith("actions_") || name.startsWith("qwertysyms_")) {
                return "";
            } else if(name.startsWith("morekeys")) {
                Log.w("KeyboardTextsTable", "Unknown morekeys text name=" + name + " locale="
                        + sTextsTableToLocaleMap.get(textsTable));
                return "";
            }
            throw new RuntimeException("Unknown text name=" + name + " locale="
                    + sTextsTableToLocaleMap.get(textsTable));
        }
        final int index = indexObj;
        final String text = (index < textsTable.length) ? textsTable[index] : null;
        if (text != null) {
            return text;
        }
        // Validity check.
        if (index >= 0 && index < TEXTS_DEFAULT.length) {
            return TEXTS_DEFAULT[index];
        }
        // Throw exception for debugging purpose.
        throw new RuntimeException("Illegal index=" + index + " for name=" + name
                + " locale=" + sTextsTableToLocaleMap.get(textsTable));
    }

    public static String[] getTextsTable(final Locale locale) {
        final String localeKey = locale.toString();
        if (sLocaleToTextsTableMap.containsKey(localeKey)) {
            return sLocaleToTextsTableMap.get(localeKey);
        }
        final String languageKey = locale.getLanguage();
        if (sLocaleToTextsTableMap.containsKey(languageKey)) {
            return sLocaleToTextsTableMap.get(languageKey);
        }
        return TEXTS_DEFAULT;
    }

    private static final String[] NAMES = {
    //  /* index:histogram */ "name",
        "locale",
        "keylabel_to_alpha",
        "morekeys_a",
        "morekeys_o",
        "morekeys_u",
        "morekeys_e",
        "morekeys_i",
        "double_quotes",
        "single_quotes",
        "morekeys_c",
        "keyspec_currency",
        "morekeys_s",
        "morekeys_misc_a",
        "morekeys_misc_o",
        "morekeys_misc_u",
        "morekeys_misc_e",
        "morekeys_n",
        "morekeys_z",
        "morekeys_misc_i",
        "morekeys_misc_s",
        "morekeys_misc_c",
        "single_angle_quotes",
        "double_angle_quotes",
        "morekeys_y",
        "keyspec_symbols_1",
        "keyspec_symbols_2",
        "keyspec_symbols_3",
        "keyspec_symbols_4",
        "keyspec_symbols_5",
        "keyspec_symbols_6",
        "keyspec_symbols_7",
        "keyspec_symbols_8",
        "keyspec_symbols_9",
        "keyspec_symbols_0",
        "additional_morekeys_symbols_1",
        "additional_morekeys_symbols_2",
        "additional_morekeys_symbols_3",
        "additional_morekeys_symbols_4",
        "additional_morekeys_symbols_5",
        "additional_morekeys_symbols_6",
        "additional_morekeys_symbols_7",
        "additional_morekeys_symbols_8",
        "additional_morekeys_symbols_9",
        "additional_morekeys_symbols_0",
        "morekeys_d",
        "morekeys_g",
        "morekeys_misc_z",
        "keylabel_to_symbol",
        "morekeys_cyrillic_ie",
        "morekeys_tablet_period",
        "morekeys_t",
        "morekeys_misc_n",
        "morekeys_nordic_row2_10",
        "morekeys_cyrillic_soft_sign",
        "morekeys_period",
        "keyspec_nordic_row1_11",
        "keyspec_nordic_row2_10",
        "keyspec_nordic_row2_11",
        "keyspec_east_slavic_row1_9",
        "keyspec_east_slavic_row2_2",
        "keyspec_east_slavic_row2_11",
        "keyspec_east_slavic_row3_5",
        "keyspec_tablet_comma",
        "keyspec_period",
        "morekeys_l",
        "morekeys_r",
        "morekeys_nordic_row2_11",
        "morekeys_punctuation",
        "morekeys_star",
        "morekeys_tablet_comma",
        "morekeys_question",
        "keyspec_left_parenthesis",
        "keyspec_right_parenthesis",
        "keyspec_left_square_bracket",
        "keyspec_right_square_bracket",
        "keyspec_left_curly_bracket",
        "keyspec_right_curly_bracket",
        "keyspec_less_than",
        "keyspec_greater_than",
        "keyspec_less_than_equal",
        "keyspec_greater_than_equal",
        "keyspec_left_double_angle_quote",
        "keyspec_right_double_angle_quote",
        "keyspec_left_single_angle_quote",
        "keyspec_right_single_angle_quote",
        "keyspec_comma",
        "keyspec_tablet_period",
        "keyhintlabel_period",
        "morekeys_misc_y",
        "morekeys_swiss_row1_11",
        "morekeys_swiss_row2_10",
        "morekeys_swiss_row2_11",
        "morekeys_bullet",
        "morekeys_left_parenthesis",
        "morekeys_right_parenthesis",
        "morekeys_arabic_diacritics",
        "morekeys_symbols_semicolon",
        "morekeys_symbols_percent",
        "keyspec_swiss_row1_11",
        "keyspec_swiss_row2_10",
        "keyspec_swiss_row2_11",
        "keyspec_spanish_row2_10",
        "keyspec_symbols_question",
        "keyspec_symbols_semicolon",
        "keyspec_symbols_percent",
        "keyhintlabel_tablet_comma",
        "keyhintlabel_tablet_period",
        "morekeys_h",
        "morekeys_j",
        "morekeys_k",
        "morekeys_misc_g",
        "morekeys_misc_l",
        "morekeys_misc_r",
        "morekeys_east_slavic_row2_2",
        "morekeys_cyrillic_u",
        "morekeys_cyrillic_en",
        "morekeys_cyrillic_ghe",
        "morekeys_cyrillic_o",
        "morekeys_cyrillic_i",
        "morekeys_tablet_punctuation",
        "keyspec_south_slavic_row1_6",
        "keyspec_south_slavic_row2_11",
        "keyspec_south_slavic_row3_1",
        "keyspec_south_slavic_row3_8",
        "label_go_key",
        "label_send_key",
        "label_next_key",
        "label_done_key",
        "label_search_key",
        "label_previous_key",
        "label_pause_key",
        "label_wait_key",
        "morekeys_w",
        "morekeys_misc_h",
        "morekeys_misc_t",
        "morekeys_east_slavic_row2_11",
        "morekeys_cyrillic_ka",
        "morekeys_cyrillic_a",
        "morekeys_currency_dollar",
        "morekeys_plus",
        "morekeys_less_than",
        "morekeys_greater_than",
        "morekeys_exclamation",
        "keyspec_q",
        "keyspec_w",
        "keyspec_y",
        "keyspec_x",
        "morekeys_b",
        "morekeys_f",
        "morekeys_m",
        "morekeys_p",
        "morekeys_q",
        "morekeys_v",
        "morekeys_x",
        "morekeys_misc_b",
        "morekeys_misc_d",
        "morekeys_misc_f",
        "morekeys_misc_j",
        "morekeys_misc_k",
        "morekeys_misc_m",
        "morekeys_misc_p",
        "morekeys_misc_q",
        "morekeys_misc_v",
        "morekeys_misc_w",
        "morekeys_misc_x",
        "morekeys_currency_generic",
        "morekeys_symbols_1",
        "morekeys_symbols_2",
        "morekeys_symbols_3",
        "morekeys_symbols_4",
        "morekeys_symbols_5",
        "morekeys_symbols_6",
        "morekeys_symbols_7",
        "morekeys_symbols_8",
        "morekeys_symbols_9",
        "morekeys_symbols_0",
        "morekeys_bottomrow_comma",
        "morekeys_am_pm",
        "morekeys_popular_domain",
        "morekeys_single_quote",
        "morekeys_double_quote",
        "morekeys_tablet_double_quote",
        "keyspec_settings",
        "keyspec_shortcut",
        "keyspec_action_next",
        "keyspec_action_previous",
        "keyspec_popular_domain",
        "keyspec_emoji_action_key",
        "keyspec_emoji_action_key_navigation",
        "keylabel_to_more_symbol",
        "keylabel_tablet_to_more_symbol",
        "keylabel_to_phone_numeric",
        "keylabel_to_phone_symbols",
        "keylabel_time_am",
        "keylabel_time_pm",
        "qwertysyms_1",
        "qwertysyms_2",
        "qwertysyms_3",
        "qwertysyms_4",
        "qwertysyms_5",
        "qwertysyms_6",
        "qwertysyms_7",
        "qwertysyms_8",
        "qwertysyms_9",
        "qwertysyms_0",
        "qwertysyms_q",
        "qwertysyms_w",
        "qwertysyms_e",
        "qwertysyms_r",
        "qwertysyms_t",
        "qwertysyms_y",
        "qwertysyms_u",
        "qwertysyms_i",
        "qwertysyms_o",
        "qwertysyms_p",
        "qwertysyms_a",
        "qwertysyms_s",
        "qwertysyms_d",
        "qwertysyms_f",
        "qwertysyms_g",
        "qwertysyms_h",
        "qwertysyms_j",
        "qwertysyms_k",
        "qwertysyms_l",
        "qwertysyms_z",
        "qwertysyms_x",
        "qwertysyms_c",
        "qwertysyms_v",
        "qwertysyms_b",
        "qwertysyms_n",
        "qwertysyms_m",
        "qwertysyms_r2_e1",
        "actions_1",
        "actions_2",
        "actions_3",
        "actions_4",
        "actions_5",
        "actions_6",
        "actions_7",
        "actions_8",
        "actions_9",
        "actions_0",
        "actions_q",
        "actions_w",
        "actions_e",
        "actions_r",
        "actions_t",
        "actions_y",
        "actions_u",
        "actions_i",
        "actions_o",
        "actions_p",
        "actions_a",
        "actions_s",
        "actions_d",
        "actions_f",
        "actions_g",
        "actions_h",
        "actions_j",
        "actions_k",
        "actions_l",
        "actions_z",
        "actions_x",
        "actions_c",
        "actions_v",
        "actions_b",
        "actions_n",
        "actions_m",
        "keyspecs_left_parenthesis_more_keys",
        "keyspecs_right_parenthesis_more_keys",
        "single_laqm_raqm",
        "single_raqm_laqm",
        "double_laqm_raqm",
        "double_raqm_laqm",
        "single_lqm_rqm",
        "single_9qm_lqm",
        "single_9qm_rqm",
        "single_rqm_9qm",
        "double_lqm_rqm",
        "double_9qm_lqm",
        "double_9qm_rqm",
        "double_rqm_9qm",
        "number_1",
        "number_2",
        "number_3",
        "number_4",
        "number_5",
        "number_6",
        "number_7",
        "number_8",
        "number_9",
        "number_0"
    };

    private static final String EMPTY = "";

    private static final String[] TEXTS_DEFAULT = {
        "DEFAULT",
        "ABC",
        EMPTY,
        EMPTY,
        EMPTY,
        EMPTY,
        EMPTY,
        "!text/double_lqm_rqm",
        "!text/single_lqm_rqm",
        EMPTY,
        "$",
        EMPTY,
        "\u00e0,\u00e1,\u00e2,\u00e4,\u00e6,\u00e3,\u00e5,\u0101",
        "\u00f3,\u00f4,\u00f6,\u00f2,\u0153,\u00f8,\u014d,\u00f5",
        "\u00fa,\u00fb,\u00fc,\u00f9,\u016b",
        "\u00e9,\u00e8,\u00ea,\u00eb,\u0113",
        EMPTY,
        EMPTY,
        "\u00ed,\u00ee,\u00ef,\u012b,\u00ec",
        "\u00df",
        "\u00e7",
        "!text/single_laqm_raqm",
        "!text/double_laqm_raqm",
        EMPTY,
        "1",
        "2",
        "3",
        "4",
        "5",
        "6",
        "7",
        "8",
        "9",
        "0",
        EMPTY,
        EMPTY,
        EMPTY,
        EMPTY,
        EMPTY,
        EMPTY,
        EMPTY,
        EMPTY,
        EMPTY,
        EMPTY,
        EMPTY,
        EMPTY,
        EMPTY,
        "?123",
        EMPTY,
        "!text/morekeys_tablet_punctuation",
        EMPTY,
        "\u00f1",
        "\u00f8",
        EMPTY,
        "!text/morekeys_punctuation",
        "\u00e5",
        "\u00f6",
        "\u00e4",
        EMPTY,
        EMPTY,
        EMPTY,
        EMPTY,
        ",",
        ".",
        EMPTY,
        EMPTY,
        "\u00e6",
        "!autoColumnOrder!8,\\,,?,!,#,!text/keyspec_right_parenthesis,!text/keyspec_left_parenthesis,/,;,',@,:,-,\",+,\\%,&",
        "\u2020,\u2021,\u2605",
        EMPTY,
        "\u00bf",
        "(",
        ")",
        "[",
        "]",
        "{",
        "}",
        "<",
        ">",
        "\u2264",
        "\u2265",
        "\u00ab",
        "\u00bb",
        "\u2039",
        "\u203a",
        ",",
        ".",
        EMPTY,
        EMPTY,
        EMPTY,
        EMPTY,
        EMPTY,
        "\u266a,\u2665,\u2660,\u2666,\u2663",
        "!autoColumnOrder!3,!text/keyspecs_left_parenthesis_more_keys",
        "!autoColumnOrder!3,!text/keyspecs_right_parenthesis_more_keys",
        EMPTY,
        EMPTY,
        "\u2030",
        EMPTY,
        EMPTY,
        EMPTY,
        "\u00f1",
        "?",
        ";",
        "%",
        EMPTY,
        EMPTY,
        EMPTY,
        EMPTY,
        EMPTY,
        EMPTY,
        EMPTY,
        EMPTY,
        EMPTY,
        EMPTY,
        EMPTY,
        EMPTY,
        EMPTY,
        EMPTY,
        "!autoColumnOrder!8,\\,,?,!,#,!text/keyspec_right_parenthesis,!text/keyspec_left_parenthesis,/,;,',@,:,-,\",+,\\%,&",
        EMPTY,
        EMPTY,
        EMPTY,
        EMPTY,
        "!string/label_go_key",
        "!string/label_send_key",
        "!string/label_next_key",
        "!string/label_done_key",
        "!string/label_search_key",
        "!string/label_previous_key",
        "!string/label_pause_key",
        "!string/label_wait_key",
        EMPTY,
        EMPTY,
        EMPTY,
        EMPTY,
        EMPTY,
        EMPTY,
        "\u00a2,\u00a3,\u20ac,\u00a5,\u20b1",
        "\u00b1",
        "!fixedColumnOrder!3,!text/keyspec_left_single_angle_quote,!text/keyspec_less_than_equal,!text/keyspec_left_double_angle_quote",
        "!fixedColumnOrder!3,!text/keyspec_right_single_angle_quote,!text/keyspec_greater_than_equal,!text/keyspec_right_double_angle_quote",
        "\u00a1,\u203d",
        "q",
        "w",
        "y",
        "x",
        EMPTY,
        EMPTY,
        EMPTY,
        EMPTY,
        EMPTY,
        EMPTY,
        EMPTY,
        EMPTY,
        EMPTY,
        EMPTY,
        EMPTY,
        EMPTY,
        EMPTY,
        EMPTY,
        EMPTY,
        EMPTY,
        EMPTY,
        EMPTY,
        "$,\u00a2,\u00a3,\u20ac,\u00a5,\u20b1",
        "\u00b9,\u2081,\u00bd,\u2153,\u00bc,\u215b",
        "\u00b2,\u2082,\u2154",
        "\u00b3,\u2083,\u00be,\u215c",
        "\u2074,\u2084",
        "\u2075,\u2085,\u215d",
        "\u2076,\u2086",
        "\u2077,\u2087,\u215e",
        "\u2078,\u2088",
        "\u2079,\u2089",
        "\u2070,\u2080,\u207f,\u2205",
        "!icon/action_settings|!code/action_settings",
        "!fixedColumnOrder!2,!hasLabels!,!text/keylabel_time_am,!text/keylabel_time_pm",
        "!hasLabels!,.net,.org,.gov,.edu",
        "!fixedColumnOrder!5,!text/single_quotes,!text/single_angle_quotes",
        "!fixedColumnOrder!5,!text/double_quotes,!text/double_angle_quotes",
        "!fixedColumnOrder!6,!text/double_quotes,!text/single_quotes,!text/double_angle_quotes,!text/single_angle_quotes",
        "!icon/settings_key|!code/key_settings",
        "!icon/shortcut_key|!code/key_shortcut",
        "!hasLabels!,!text/label_next_key|!code/key_action_next",
        "!hasLabels!,!text/label_previous_key|!code/key_action_previous",
        ".com",
        "!fixedColumnOrder!4,!needsDividers!,!icon/action_switch_language|!code/action_switch_language,!icon/action_text_edit|!code/action_text_edit,!icon/action_clipboard_history|!code/action_clipboard_history,!icon/action_emoji|!code/action_emoji,!icon/action_undo|!code/action_undo,!icon/action_redo|!code/action_redo",
        "!fixedColumnOrder!4,!needsDividers!,!icon/action_switch_language|!code/action_switch_language,!icon/action_text_edit|!code/action_text_edit,!icon/action_clipboard_history|!code/action_clipboard_history,!icon/action_emoji|!code/action_emoji,!icon/previous_key|!code/key_action_previous,!icon/next_key|!code/key_action_next,!icon/action_undo|!code/action_undo,!icon/action_redo|!code/action_redo",
        "= \\\\ <",
        "~ [ <",
        "123",
        "\uff0a\uff03",
        "AM",
        "PM",
        "!",
        "@",
        "#",
        "$",
        "%",
        "^",
        "&",
        "*",
        "(",
        ")",
        "\\%",
        "\\\\",
        "|",
        "=",
        "[",
        "]",
        "<",
        ">",
        "{",
        "}",
        "@",
        "#",
        "!text/keyspec_currency,$",
        "\\%",
        "&,|",
        "-,\u2013,\u2014,_",
        "+,=",
        "(,[,{,<",
        "),],},>",
        "*",
        "\"",
        "'",
        ":",
        ";",
        "!",
        "?,/",
        "/",
        EMPTY,
        EMPTY,
        EMPTY,
        EMPTY,
        EMPTY,
        EMPTY,
        EMPTY,
        EMPTY,
        EMPTY,
        EMPTY,
        EMPTY,
        EMPTY,
        EMPTY,
        EMPTY,
        EMPTY,
        "!icon/action_redo|!code/action_redo",
        EMPTY,
        EMPTY,
        EMPTY,
        EMPTY,
        "!icon/action_select_all|!code/action_select_all",
        EMPTY,
        EMPTY,
        EMPTY,
        EMPTY,
        EMPTY,
        EMPTY,
        EMPTY,
        EMPTY,
        "!icon/action_undo|!code/action_undo",
        "!icon/action_cut|!code/action_cut",
        "!icon/action_copy|!code/action_copy",
        "!icon/action_paste|!code/action_paste",
        EMPTY,
        EMPTY,
        EMPTY,
        "!text/keyspec_less_than,!text/keyspec_left_curly_bracket,!text/keyspec_left_square_bracket",
        "!text/keyspec_greater_than,!text/keyspec_right_curly_bracket,!text/keyspec_right_square_bracket",
        "!text/keyspec_left_single_angle_quote,!text/keyspec_right_single_angle_quote",
        "!text/keyspec_right_single_angle_quote,!text/keyspec_left_single_angle_quote",
        "!text/keyspec_left_double_angle_quote,!text/keyspec_right_double_angle_quote",
        "!text/keyspec_right_double_angle_quote,!text/keyspec_left_double_angle_quote",
        "\u201a,\u2018,\u2019",
        "\u2019,\u201a,\u2018",
        "\u2018,\u201a,\u2019",
        "\u2018,\u2019,\u201a",
        "\u201e,\u201c,\u201d",
        "\u201d,\u201e,\u201c",
        "\u201c,\u201e,\u201d",
        "\u201c,\u201d,\u201e",
        "1",
        "2",
        "3",
        "4",
        "5",
        "6",
        "7",
        "8",
        "9",
        "0"
    };

    private static final String[] TEXTS_af = {
        "af",
        null,
        "\u00e1",
        "\u00f3,\u00f4",
        "\u00fa,\u00fb",
        "\u00e9,\u00e8,\u00ea,\u00eb",
        "\u00ed,\u00ec,\u00ef,\u00ee",
        null,
        null,
        null,
        null,
        null,
        "\u00e2,\u00e4,\u00e0,\u00e6,\u00e3,\u00e5,\u0101",
        "\u00f6,\u00f2,\u00f5,\u0153,\u00f8,\u014d",
        "\u00fc,\u00f9,\u016b",
        "\u0119,\u0117,\u0113",
        null,
        null,
        "\u012f,\u012b,\u0133"
    };

    private static final String[] TEXTS_ar = {
        "ar",
        "\u0623\u200c\u0628\u200c\u062c",
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        "\u0661",
        "\u0662",
        "\u0663",
        "\u0664",
        "\u0665",
        "\u0666",
        "\u0667",
        "\u0668",
        "\u0669",
        "\u0660",
        "1",
        "2",
        "3",
        "4",
        "5",
        "6",
        "7",
        "8",
        "9",
        "0,\u066b,\u066c",
        null,
        null,
        null,
        "\u0663\u0662\u0661\u061f",
        null,
        "!text/morekeys_arabic_diacritics",
        null,
        null,
        null,
        null,
        "!text/morekeys_arabic_diacritics",
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        "\u060c",
        null,
        null,
        null,
        null,
        null,
        "\u2605,\u066d",
        "!fixedColumnOrder!4,:,!,\u061f,\u061b,-,\\\",\\'",
        "?,\u00bf",
        "(|)",
        ")|(",
        "[|]",
        "]|[",
        "{|}",
        "}|{",
        "<|>",
        ">|<",
        "\u2264|\u2265",
        "\u2265|\u2264",
        "\u00ab|\u00bb",
        "\u00bb|\u00ab",
        "\u2039|\u203a",
        "\u203a|\u2039",
        "\u060c",
        null,
        "\u0651",
        null,
        null,
        null,
        null,
        "\u266a",
        "!fixedColumnOrder!4,\ufd3e|\ufd3f,!text/keyspecs_left_parenthesis_more_keys",
        "!fixedColumnOrder!4,\ufd3f|\ufd3e,!text/keyspecs_right_parenthesis_more_keys",
        "!fixedColumnOrder!8, \u0654\u25cc|\u0654, \u0652\u25cc|\u0652, \u064d\u25cc|\u064d, \u064c\u25cc|\u064c, \u0651\u25cc|\u0651, \u064b\u25cc|\u064b,!text/keyspec_symbols_question,!, \u0656\u25cc|\u0656, \u0670\u25cc|\u0670, \u0653\u25cc|\u0653, \u0650\u25cc|\u0650, \u064f\u25cc|\u064f,\u0640, \u0655\u25cc|\u0655, \u064e\u25cc|\u064e",
        ";",
        "\\%,\u2030",
        null,
        null,
        null,
        null,
        "\u061f",
        "\u061b",
        "\u066a",
        "\u061f",
        "\u0651"
    };

    private static final String[] TEXTS_az = {
        "az",
        null,
        "\u00e2,\u00e4,\u00e1",
        "\u00f6,\u00f4,\u0153,\u00f2,\u00f3,\u00f5,\u00f8,\u014d",
        "\u00fc,\u00fb,\u00f9,\u00fa,\u016b",
        "\u0259,\u00e9",
        "\u0131,\u00ee,\u00ef,\u00ec,\u00ed,\u012f,\u012b",
        null,
        null,
        "\u00e7,\u0107,\u010d",
        null,
        "\u015f,\u00df,\u015b,\u0161",
        null,
        null,
        null,
        null,
        "\u0148,\u00f1",
        "\u017e",
        null,
        null,
        null,
        null,
        null,
        "\u00fd",
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        "\u011f"
    };

    private static final String[] TEXTS_be = {
        "be",
        "\u0410\u0411\u0412",
        null,
        null,
        null,
        null,
        null,
        "!text/double_9qm_lqm",
        "!text/single_9qm_lqm",
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        "\u0451",
        null,
        null,
        null,
        null,
        "\u044a",
        null,
        null,
        null,
        null,
        "\u045e",
        "\u044b",
        "\u044d",
        "\u0456"
    };

    private static final String[] TEXTS_bg = {
        "bg",
        "\u0410\u0411\u0412",
        null,
        null,
        null,
        null,
        null,
        "!text/double_9qm_lqm"
    };

    private static final String[] TEXTS_bn_BD = {
        "bn_BD",
        "\u0995\u0996\u0997",
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        "\u09f3",
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        "\u09e7",
        "\u09e8",
        "\u09e9",
        "\u09ea",
        "\u09eb",
        "\u09ec",
        "\u09ed",
        "\u09ee",
        "\u09ef",
        "\u09e6",
        "1",
        "2",
        "3",
        "4",
        "5",
        "6",
        "7",
        "8",
        "9",
        "0"
    };

    private static final String[] TEXTS_bn_IN = {
        "bn_IN",
        "\u0995\u0996\u0997",
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        "\u20b9"
    };

    private static final String[] TEXTS_ca = {
        "ca",
        null,
        "\u00e0",
        "\u00f2,\u00f3",
        "\u00fa,\u00fc",
        "\u00e8,\u00e9",
        "\u00ed,\u00ef",
        null,
        null,
        "\u00e7",
        null,
        null,
        "\u00e1,\u00e4,\u00e2,\u00e3,\u00e5,\u0105,\u00e6,\u0101,\u00aa",
        "\u00f6,\u00f4,\u00f5,\u00f8,\u0153,\u014d,\u00ba",
        "\u00f9,\u00fb,\u016b",
        "\u00eb,\u00ea,\u0119,\u0117,\u0113",
        null,
        null,
        "\u00ec,\u00ee,\u012f,\u012b",
        null,
        "\u0107,\u010d",
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        "!autoColumnOrder!9,\\\\,?,!,\u00b7,#,),(,/,;,',@,:,-,\\\",+,\\%,&",
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        "\u00e7",
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        "!autoColumnOrder!8,\\\\,',\u00b7,#,),(,/,;,@,:,-,\\\",+,\\%,&"
    };

    private static final String[] TEXTS_ckb = {
        "ckb",
        "\u0623\u200c\u0628\u200c\u062c",
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        "\u0661",
        "\u0662",
        "\u0663",
        "\u0664",
        "\u0665",
        "\u0666",
        "\u0667",
        "\u0668",
        "\u0669",
        "\u0660",
        "1",
        "2",
        "3",
        "4",
        "5",
        "6",
        "7",
        "8",
        "9",
        "0,\u066b,\u066c",
        null,
        null,
        null,
        "\u0663\u0662\u0661\u061f",
        null,
        "\u061f",
        null,
        null,
        null,
        null,
        "\u061f",
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        "\u060c",
        ".",
        null,
        null,
        null,
        null,
        "\u2605,\u066d",
        "!fixedColumnOrder!4,:,!,\u061f,\u061b,-,\\\",\\'",
        "?,\u00bf",
        "(|)",
        ")|(",
        "[|]",
        "]|[",
        "{|}",
        "}|{",
        "<|>",
        ">|<",
        "\u2264|\u2265",
        "\u2265|\u2264",
        "\u00ab|\u00bb",
        "\u00bb|\u00ab",
        "\u2039|\u203a",
        "\u203a|\u2039",
        "\u060c",
        null,
        "\u0651",
        null,
        null,
        null,
        null,
        "\u266a",
        "!fixedColumnOrder!4,\ufd3e|\ufd3f,!text/keyspecs_left_parenthesis_more_keys",
        "!fixedColumnOrder!4,\ufd3f|\ufd3e,!text/keyspecs_right_parenthesis_more_keys",
        "!fixedColumnOrder!7, \u0655\u25cc|\u0655, \u0654\u25cc|\u0654, \u0652\u25cc|\u0652, \u064d\u25cc|\u064d, \u064c\u25cc|\u064c, \u064b\u25cc|\u064b, \u0651\u25cc|\u0651, \u0656\u25cc|\u0656, \u0670\u25cc|\u0670, \u0653\u25cc|\u0653, \u0650\u25cc|\u0650, \u064f\u25cc|\u064f, \u064e\u25cc|\u064e,\u0640|\u0640",
        ";",
        "\\%,\u2030",
        null,
        null,
        null,
        null,
        "\u061f",
        "\u061b",
        "\u066a",
        "\u061f",
        "\u0651"
    };

    private static final String[] TEXTS_cs = {
        "cs",
        null,
        "\u00e1",
        "\u00f3",
        "\u00fa,\u016f",
        "\u00e9,\u011b",
        "\u00ed",
        "!text/double_9qm_lqm",
        "!text/single_9qm_lqm",
        "\u010d",
        null,
        "\u0161",
        "\u00e0,\u00e2,\u00e4,\u00e6,\u00e3,\u00e5,\u0101",
        "\u00f6,\u00f4,\u00f2,\u00f5,\u0153,\u00f8,\u014d",
        "\u00fb,\u00fc,\u00f9,\u016b",
        "\u00e8,\u00ea,\u00eb,\u0119,\u0117,\u0113",
        "\u0148",
        "\u017e",
        "\u00ee,\u00ef,\u00ec,\u012f,\u012b",
        "\u00df,\u015b",
        "\u00e7,\u0107",
        "!text/single_raqm_laqm",
        "!text/double_raqm_laqm",
        "\u00fd",
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        "\u010f",
        null,
        "\u017a,\u017c",
        null,
        null,
        null,
        "\u0165",
        "\u00f1,\u0144",
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        "\u0159",
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        "\u00ff"
    };

    private static final String[] TEXTS_da = {
        "da",
        null,
        "\u00e5,\u00e6",
        "\u00f8",
        null,
        null,
        null,
        "!text/double_9qm_lqm",
        "!text/single_9qm_lqm",
        null,
        null,
        null,
        "\u00e1,\u00e4,\u00e0,\u00e2,\u00e3,\u0101",
        "\u00f6,\u00f3,\u00f4,\u00f2,\u00f5,\u0153,\u014d",
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        "!text/single_raqm_laqm",
        "!text/double_raqm_laqm",
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        "\u00e4",
        null,
        null,
        "\u00e5",
        "\u00e6",
        "\u00f8",
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        "\u00f6"
    };

    private static final String[] TEXTS_de = {
        "de",
        null,
        "\u00e4",
        "\u00f6",
        "\u00fc",
        null,
        null,
        "!text/double_9qm_lqm",
        "!text/single_9qm_lqm",
        null,
        null,
        "\u00df",
        "%,\u00e2,\u00e0,\u00e1,\u00e6,\u00e3,\u00e5,\u0101",
        "%,\u00f4,\u00f2,\u00f3,\u00f5,\u0153,\u00f8,\u014d",
        "%,\u00fb,\u00f9,\u00fa,\u016b",
        null,
        null,
        null,
        null,
        "\u015b,\u0161",
        null,
        "!text/single_raqm_laqm",
        "!text/double_raqm_laqm",
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        "\u00e8",
        "\u00e9",
        "\u00e0",
        null,
        null,
        null,
        null,
        null,
        null,
        "\u00fc",
        "\u00f6",
        "\u00e4"
    };

    private static final String[] TEXTS_el = {
        "el",
        "\u0391\u0392\u0393"
    };

    private static final String[] TEXTS_en = {
        "en"
    };

    private static final String[] TEXTS_eo = {
        "eo",
        null,
        null,
        null,
        "\u016d",
        null,
        null,
        null,
        null,
        "\u0109",
        null,
        "\u015d",
        null,
        null,
        "\u00fa,\u016f,\u00fb,\u00fc,\u00f9,\u016b,\u0169,\u0171,\u0173,\u00b5",
        null,
        null,
        null,
        null,
        "\u00df,\u0161,\u015b,\u0219,\u015f",
        "\u0107,\u010d,\u00e7,\u010b",
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        "\u011d",
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        "\u0135",
        null,
        null,
        null,
        null,
        null,
        "\u0125",
        "\u0135",
        null,
        "\u011f,\u0121,\u0123",
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        "\u0127",
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        "\u015d",
        "\u011d",
        "\u016d",
        "\u0109"
    };

    private static final String[] TEXTS_es = {
        "es",
        null,
        "\u00e1",
        "\u00f3",
        "\u00fa,\u00fc",
        "\u00e9",
        "\u00ed",
        null,
        null,
        null,
        null,
        null,
        "\u00e0,\u00e4,\u00e2,\u00e3,\u00e5,\u0105,\u00e6,\u0101,\u00aa",
        "\u00f2,\u00f6,\u00f4,\u00f5,\u00f8,\u0153,\u014d,\u00ba",
        "\u00f9,\u00fb,\u016b",
        "\u00e8,\u00eb,\u00ea,\u0119,\u0117,\u0113",
        "\u00f1",
        null,
        "\u00ef,\u00ec,\u00ee,\u012f,\u012b",
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        "\u0144",
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        "!autoColumnOrder!9,\\\\,?,!,#,),(,/,;,\u00a1,',@,:,-,\\\",+,\\%,&,\u00bf"
    };

    private static final String[] TEXTS_et = {
        "et",
        null,
        "\u00e4",
        "\u00f6,\u00f5",
        "\u00fc",
        null,
        null,
        "!text/double_9qm_lqm",
        "!text/single_9qm_lqm",
        null,
        null,
        "\u0161",
        "\u0101,\u00e0,\u00e1,\u00e2,\u00e3,\u00e5,\u00e6,\u0105",
        "\u00f2,\u00f3,\u00f4,\u0153,\u0151,\u00f8",
        "\u016b,\u0173,\u00f9,\u00fa,\u00fb,\u016f,\u0171",
        null,
        null,
        "\u017e",
        null,
        "\u00df,\u015b,\u015f",
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        "\u017c,\u017a",
        null,
        null,
        null,
        null,
        null,
        "\u00f5",
        null,
        null,
        "\u00fc",
        "\u00f6",
        "\u00e4"
    };

    private static final String[] TEXTS_eu = {
        "eu",
        null,
        "\u00e1,\u00e0,\u00e4,\u00e2,\u00e3,\u00e5,\u0105,\u00e6,\u0101,\u00aa",
        "\u00f3,\u00f2,\u00f6,\u00f4,\u00f5,\u00f8,\u0153,\u014d,\u00ba",
        "\u00fa,\u00fc,\u00f9,\u00fb,\u016b",
        "\u00e9,\u00e8,\u00eb,\u00ea,\u0119,\u0117,\u0113",
        "\u00ed,\u00ef,\u00ec,\u00ee,\u012f,\u012b",
        null,
        null,
        "\u00e7,\u0107,\u010d",
        null,
        null,
        null,
        null,
        null,
        null,
        "\u00f1,\u0144"
    };

    private static final String[] TEXTS_fa = {
        "fa",
        "\u0627\u200c\u0628\u200c\u067e",
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        "\ufdfc",
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        "\u06f1",
        "\u06f2",
        "\u06f3",
        "\u06f4",
        "\u06f5",
        "\u06f6",
        "\u06f7",
        "\u06f8",
        "\u06f9",
        "\u06f0",
        "1",
        "2",
        "3",
        "4",
        "5",
        "6",
        "7",
        "8",
        "9",
        "0,\u066b,\u066c",
        null,
        null,
        null,
        "\u06f3\u06f2\u06f1\u061f",
        null,
        "!text/morekeys_arabic_diacritics",
        null,
        null,
        null,
        null,
        "!text/morekeys_arabic_diacritics",
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        "\u060c",
        null,
        null,
        null,
        null,
        null,
        "\u2605,\u066d",
        "!fixedColumnOrder!4,:,!,\u061f,\u061b,-,!text/keyspec_left_double_angle_quote,!text/keyspec_right_double_angle_quote",
        "?,\u00bf",
        "(|)",
        ")|(",
        "[|]",
        "]|[",
        "{|}",
        "}|{",
        "<|>",
        ">|<",
        "\u2264|\u2265",
        "\u2265|\u2264",
        "\u00ab|\u00bb",
        "\u00bb|\u00ab",
        "\u2039|\u203a",
        "\u203a|\u2039",
        "\u060c",
        null,
        "\u064b",
        null,
        null,
        null,
        null,
        "\u266a",
        "!fixedColumnOrder!4,\ufd3e|\ufd3f,!text/keyspecs_left_parenthesis_more_keys",
        "!fixedColumnOrder!4,\ufd3f|\ufd3e,!text/keyspecs_right_parenthesis_more_keys",
        "!fixedColumnOrder!8, \u0654\u25cc|\u0654, \u0652\u25cc|\u0652, \u064d\u25cc|\u064d, \u064c\u25cc|\u064c, \u0651\u25cc|\u0651, \u064b\u25cc|\u064b,!text/keyspec_symbols_question,!, \u0656\u25cc|\u0656, \u0670\u25cc|\u0670, \u0653\u25cc|\u0653, \u0650\u25cc|\u0650, \u064f\u25cc|\u064f,\u0640, \u0655\u25cc|\u0655, \u064e\u25cc|\u064e",
        ";",
        "\\%,\u2030",
        null,
        null,
        null,
        null,
        "\u061f",
        "\u061b",
        "\u066a",
        "\u061f",
        "\u064b",
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        "!fixedColumnOrder!3,!text/keyspec_left_single_angle_quote,!text/keyspec_less_than_equal,!text/keyspec_less_than",
        "!fixedColumnOrder!3,!text/keyspec_right_single_angle_quote,!text/keyspec_greater_than_equal,!text/keyspec_greater_than"
    };

    private static final String[] TEXTS_fi = {
        "fi",
        null,
        "\u00e4,\u00e5",
        "\u00f6",
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        "\u0161",
        "\u00e6,\u00e0,\u00e1,\u00e2,\u00e3,\u0101",
        "\u00f8,\u00f4,\u00f2,\u00f3,\u00f5,\u0153,\u014d",
        null,
        null,
        null,
        "\u017e",
        null,
        "\u00df,\u015b",
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        "\u017a,\u017c",
        null,
        null,
        null,
        null,
        null,
        "\u00f8",
        null,
        null,
        "\u00e5",
        "\u00f6",
        "\u00e4",
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        "\u00e6"
    };

    private static final String[] TEXTS_fr = {
        "fr",
        null,
        "\u00e0,\u00e2,%,\u00e6",
        "\u00f4,\u0153",
        "\u00f9,\u00fb,%,\u00fc",
        "\u00e9,\u00e8,\u00ea,\u00eb",
        "\u00ee,%,\u00ef",
        null,
        null,
        "\u00e7",
        null,
        null,
        "\u00e1,\u00e4,\u00e3,\u00e5,\u0101,\u00aa",
        "%,\u00f6,\u00f2,\u00f3,\u00f5,\u00f8,\u014d,\u00ba",
        "\u00fa,\u016b",
        "%,\u0119,\u0117,\u0113",
        null,
        null,
        "\u00ec,\u00ed,\u012f,\u012b",
        null,
        "%,\u0107,\u010d",
        null,
        null,
        "%,\u00ff",
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        "\u00fc",
        "\u00f6",
        "\u00e4",
        null,
        null,
        null,
        null,
        null,
        null,
        "\u00e8",
        "\u00e9",
        "\u00e0"
    };

    private static final String[] TEXTS_gl = {
        "gl",
        null,
        "\u00e1,\u00e0,\u00e4,\u00e2,\u00e3,\u00e5,\u0105,\u00e6,\u0101,\u00aa",
        "\u00f3,\u00f2,\u00f6,\u00f4,\u00f5,\u00f8,\u0153,\u014d,\u00ba",
        "\u00fa,\u00fc,\u00f9,\u00fb,\u016b",
        "\u00e9,\u00e8,\u00eb,\u00ea,\u0119,\u0117,\u0113",
        "\u00ed,\u00ef,\u00ec,\u00ee,\u012f,\u012b",
        null,
        null,
        "\u00e7,\u0107,\u010d",
        null,
        null,
        null,
        null,
        null,
        null,
        "\u00f1,\u0144"
    };

    private static final String[] TEXTS_hi = {
        "hi",
        "\u0915\u0916\u0917",
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        "\u20b9",
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        "\u0967",
        "\u0968",
        "\u0969",
        "\u096a",
        "\u096b",
        "\u096c",
        "\u096d",
        "\u096e",
        "\u096f",
        "\u0966",
        "1",
        "2",
        "3",
        "4",
        "5",
        "6",
        "7",
        "8",
        "9",
        "0",
        null,
        null,
        null,
        "?\u0967\u0968\u0969",
        null,
        "!autoColumnOrder!8,.,\\,,?,!,\u0965,#,),(,',/,@,:,;,-,\",+",
        null,
        null,
        null,
        null,
        "!autoColumnOrder!8,\\,,.,?,!,\u0965,#,),(,/,',@,:,;,-,\",+",
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        "\u0964",
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        "\u0964"
    };

    private static final String[] TEXTS_hi_ZZ = {
        "hi_ZZ",
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        "\u20b9",
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        "Go",
        "Send",
        "Next",
        "Done",
        "Search",
        "Prev",
        "Pause",
        "Wait"
    };

    private static final String[] TEXTS_hr = {
        "hr",
        null,
        null,
        null,
        null,
        null,
        null,
        "!text/double_9qm_rqm",
        "!text/single_9qm_rqm",
        "\u010d,\u0107",
        null,
        "\u0161",
        null,
        null,
        null,
        null,
        null,
        "\u017e",
        null,
        "\u015b,\u00df",
        "\u00e7",
        "!text/single_raqm_laqm",
        "!text/double_raqm_laqm",
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        "\u0111",
        null,
        "\u017a,\u017c"
    };

    private static final String[] TEXTS_hu = {
        "hu",
        null,
        "\u00e1",
        "\u00f3,\u00f6,\u0151",
        "\u00fa,\u00fc,\u0171",
        "\u00e9",
        "\u00ed",
        "!text/double_9qm_rqm",
        "!text/single_9qm_rqm",
        null,
        null,
        null,
        "\u00e0,\u00e2,\u00e4,\u00e6,\u00e3,\u00e5,\u0101",
        "\u00f4,\u00f2,\u00f5,\u0153,\u00f8,\u014d",
        "\u00fb,\u00f9,\u016b",
        "\u00e8,\u00ea,\u00eb,\u0119,\u0117,\u0113",
        null,
        null,
        "\u00ee,\u00ef,\u00ec,\u012f,\u012b",
        null,
        null,
        "!text/single_raqm_laqm",
        "!text/double_raqm_laqm"
    };

    private static final String[] TEXTS_hy = {
        "hy",
        "\u0531\u0532\u0533",
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        "\u058f",
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        "!text/morekeys_punctuation",
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        "\u055d",
        "\u0589",
        null,
        null,
        null,
        "!autoColumnOrder!8,\\,,\u055e,\u055c,.,\u055a,\u0559,?,!,\u055d,\u055b,\u058a,\u00bb,\u00ab,\u055f,;,:",
        null,
        null,
        "\u055e,\u00bf",
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        "\u055d",
        "\u0589",
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        "\u055c,\u00a1"
    };

    private static final String[] TEXTS_is = {
        "is",
        null,
        "\u00e1,\u00e4,\u00e6",
        "\u00f3,\u00f6",
        "\u00fa",
        "\u00e9",
        "\u00ed",
        "!text/double_9qm_lqm",
        "!text/single_9qm_lqm",
        null,
        null,
        null,
        "\u00e5,\u00e0,\u00e2,\u00e3,\u0101",
        "\u00f4,\u00f2,\u00f5,\u0153,\u00f8,\u014d",
        "\u00fc,\u00fb,\u00f9,\u016b",
        "\u00eb,\u00e8,\u00ea,\u0119,\u0117,\u0113",
        null,
        null,
        "\u00ef,\u00ee,\u00ec,\u012f,\u012b",
        null,
        null,
        null,
        null,
        "\u00fd",
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        "\u00f0",
        null,
        null,
        null,
        null,
        null,
        "\u00fe",
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        "\u00ff"
    };

    private static final String[] TEXTS_it = {
        "it",
        null,
        "\u00e0",
        "\u00f2",
        "\u00f9",
        "\u00e8,\u00e9",
        "\u00ec",
        null,
        null,
        null,
        null,
        null,
        "\u00e1,\u00e2,\u00e4,\u00e6,\u00e3,\u00e5,\u0101,\u00aa",
        "\u00f3,\u00f4,\u00f6,\u00f5,\u0153,\u00f8,\u014d,\u00ba",
        "\u00fa,\u00fb,\u00fc,\u016b",
        "\u00ea,\u00eb,\u0119,\u0117,\u0113",
        null,
        null,
        "\u00ed,\u00ee,\u00ef,\u012f,\u012b",
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        "\u00e8",
        "\u00e9",
        "\u00e0",
        null,
        null,
        null,
        null,
        null,
        null,
        "\u00fc",
        "\u00f6",
        "\u00e4"
    };

    private static final String[] TEXTS_iw = {
        "iw",
        "\u05d0\u05d1\u05d2",
        null,
        null,
        null,
        null,
        null,
        "!text/double_rqm_9qm",
        "!text/single_rqm_9qm",
        null,
        "\u20aa",
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        "\u2605",
        null,
        null,
        "(|)",
        ")|(",
        "[|]",
        "]|[",
        "{|}",
        "}|{",
        "<|>",
        ">|<",
        "\u2264|\u2265",
        "\u2265|\u2264",
        "\u00ab|\u00bb",
        "\u00bb|\u00ab",
        "\u2039|\u203a",
        "\u203a|\u2039",
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        "\u00b1,\ufb29"
    };

    private static final String[] TEXTS_ka = {
        "ka",
        "\u10d0\u10d1\u10d2",
        null,
        null,
        null,
        null,
        null,
        "!text/double_9qm_lqm",
        "!text/single_9qm_lqm"
    };

    private static final String[] TEXTS_kk = {
        "kk",
        "\u0410\u0411\u0412",
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        "\u0451",
        null,
        null,
        null,
        null,
        "\u044a",
        null,
        null,
        null,
        null,
        "\u0449",
        "\u044b",
        "\u044d",
        "\u0438",
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        "\u0456",
        "\u04af,\u04b1",
        "\u04a3",
        "\u0493",
        "\u04e9",
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        "\u04bb",
        "\u049b",
        "\u04d9"
    };

    private static final String[] TEXTS_km = {
        "km",
        "\u1780\u1781\u1782",
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        "\u17db,\u00a2,\u00a3,\u20ac,\u00a5,\u20b1"
    };

    private static final String[] TEXTS_kn = {
        "kn",
        "\u0c85\u0c86\u0c87",
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        "\u20b9",
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        "\u0ce7",
        "\u0ce8",
        "\u0ce9",
        "\u0cea",
        "\u0ceb",
        "\u0cec",
        "\u0ced",
        "\u0cee",
        "\u0cef",
        "\u0ce6",
        "1",
        "2",
        "3",
        "4",
        "5",
        "6",
        "7",
        "8",
        "9",
        "0",
        null,
        null,
        null,
        "?\u0ce7\u0ce8\u0ce9"
    };

    private static final String[] TEXTS_ky = {
        "ky",
        "\u0410\u0411\u0412",
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        "\u0451",
        null,
        null,
        null,
        null,
        "\u044a",
        null,
        null,
        null,
        null,
        "\u0449",
        "\u044b",
        "\u044d",
        "\u0438",
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        "\u04af",
        "\u04a3",
        null,
        "\u04e9"
    };

    private static final String[] TEXTS_lo = {
        "lo",
        "\u0e81\u0e82\u0e84",
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        "\u20ad"
    };

    private static final String[] TEXTS_lt = {
        "lt",
        null,
        "\u0105",
        null,
        "\u016b,\u0173",
        "\u0117,\u0119",
        "\u012f",
        "\u201d,\u201e,\u201c",
        "\u2019,\u201a,\u2018",
        "\u010d",
        null,
        "\u0161",
        null,
        null,
        null,
        null,
        null,
        "\u017e"
    };

    private static final String[] TEXTS_lv = {
        "lv",
        null,
        "\u0101",
        "\u014d",
        "\u016b",
        "\u0113",
        "\u012b",
        "!text/double_9qm_lqm",
        "!text/single_9qm_lqm",
        "\u010d",
        null,
        "\u0161",
        "\u00e0,\u00e1,\u00e2,\u00e3,\u00e4,\u00e5,\u00e6,\u0105",
        "\u00f2,\u00f3,\u00f4,\u00f5,\u00f6,\u0153,\u0151,\u00f8",
        "\u0173,\u00f9,\u00fa,\u00fb,\u00fc,\u016f,\u0171",
        "\u0117,\u00e8,\u00e9,\u00ea,\u00eb,\u0119,\u011b",
        "\u0146",
        "\u017e",
        "\u012f,\u00ec,\u00ed,\u00ee,\u00ef,\u0131",
        "\u00df,\u015b,\u015f",
        "\u00e7,\u0107",
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        "\u0123",
        "\u017c,\u017a",
        null,
        null,
        null,
        null,
        "\u00f1,\u0144",
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        "\u013c",
        "\u0157",
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        "\u0137",
        "\u011f",
        "\u0142,\u013a,\u013e",
        "\u0159,\u0155"
    };

    private static final String[] TEXTS_mk = {
        "mk",
        "\u0410\u0411\u0412",
        null,
        null,
        null,
        null,
        null,
        "!text/double_9qm_lqm",
        "!text/single_9qm_lqm",
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        "\u0450",
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        "\u045d",
        null,
        "\u0455",
        "\u045c",
        "\u0437",
        "\u0453"
    };

    private static final String[] TEXTS_ml = {
        "ml",
        "\u0d05",
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        "\u20b9"
    };

    private static final String[] TEXTS_mn = {
        "mn",
        "\u0410\u0411\u0412",
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        "\u20ae"
    };

    private static final String[] TEXTS_mr = {
        "mr",
        "\u0915\u0916\u0917",
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        "\u20b9",
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        "\u0967",
        "\u0968",
        "\u0969",
        "\u096a",
        "\u096b",
        "\u096c",
        "\u096d",
        "\u096e",
        "\u096f",
        "\u0966",
        "1",
        "2",
        "3",
        "4",
        "5",
        "6",
        "7",
        "8",
        "9",
        "0",
        null,
        null,
        null,
        "?\u0967\u0968\u0969"
    };

    private static final String[] TEXTS_my = {
        "my",
        "\u1000\u1001\u1002",
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        "\u104a",
        "\u104b",
        null,
        null,
        null,
        "!autoColumnOrder!9,\u104a,.,?,!,#,),(,/,;,...,',@,:,-,\\\",+,\\%,&",
        null,
        "\\",
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        "\u104b",
        "\u104a",
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        "!autoColumnOrder!8,.,',#,),(,/,;,@,...,:,-,\\\",+,\\%,&"
    };

    private static final String[] TEXTS_nb = {
        "nb",
        null,
        "\u00e5,\u00e6,\u00e4,\u00e0,\u00e1,\u00e2,\u00e3,\u0101",
        "\u00f8,\u00f6,\u00f4,\u00f2,\u00f3,\u00f5,\u0153,\u014d",
        "\u00fc,\u00fb,\u00f9,\u00fa,\u016b",
        "\u00e9,\u00e8,\u00ea,\u00eb,\u0119,\u0117,\u0113",
        null,
        "!text/double_9qm_rqm",
        "!text/single_9qm_rqm",
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        "\u00f6",
        null,
        null,
        "\u00e5",
        "\u00f8",
        "\u00e6",
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        "\u00e4"
    };

    private static final String[] TEXTS_ne = {
        "ne",
        "\u0915\u0916\u0917",
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        "\u0930\u0941.",
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        "\u0967",
        "\u0968",
        "\u0969",
        "\u096a",
        "\u096b",
        "\u096c",
        "\u096d",
        "\u096e",
        "\u096f",
        "\u0966",
        "1",
        "2",
        "3",
        "4",
        "5",
        "6",
        "7",
        "8",
        "9",
        "0",
        null,
        null,
        null,
        "?\u0967\u0968\u0969",
        null,
        "!autoColumnOrder!8,.,\\,,?,!,\u0965,#,),(,',/,@,:,;,-,\",+",
        null,
        null,
        null,
        null,
        "!autoColumnOrder!8,\\,,.,?,!,\u0965,#,),(,/,',@,:,;,-,\",+",
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        "\u0964",
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        "\u0964"
    };

    private static final String[] TEXTS_nl = {
        "nl",
        null,
        "\u00e1,\u00e4,\u00e2,\u00e0",
        "\u00f3,\u00f6",
        "\u00fa,\u00fc",
        "\u00e9,\u00eb,\u00ea,\u00e8",
        "\u00ed,\u00ef,\u00ec,\u00ee,\u012f,\u012b,\u0133",
        "!text/double_9qm_rqm",
        "!text/single_9qm_rqm",
        null,
        null,
        null,
        "\u00e6,\u00e3,\u00e5,\u0101",
        "\u00f4,\u00f2,\u00f5,\u0153,\u00f8,\u014d",
        "\u00fb,\u00f9,\u016b",
        "\u0119,\u0117,\u0113"
    };

    private static final String[] TEXTS_pl = {
        "pl",
        null,
        "\u0105",
        "\u00f3",
        null,
        "\u0119",
        null,
        "!text/double_9qm_rqm",
        "!text/single_9qm_rqm",
        "\u0107",
        null,
        "\u015b",
        "\u00e1,\u00e0,\u00e2,\u00e4,\u00e6,\u00e3,\u00e5,\u0101",
        "\u00f6,\u00f4,\u00f2,\u00f5,\u0153,\u00f8,\u014d",
        null,
        "\u00e8,\u00e9,\u00ea,\u00eb,\u0117,\u0113",
        "\u0144",
        "\u017c,\u017a",
        null,
        "\u00df,\u0161",
        "\u00e7,\u010d",
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        "\u017e",
        null,
        null,
        null,
        null,
        "\u00f1",
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        "\u0142"
    };

    private static final String[] TEXTS_pt = {
        "pt",
        null,
        "\u00e1,\u00e3,\u00e0,\u00e2",
        "\u00f3,\u00f5,\u00f4",
        "\u00fa,\u00fc",
        "\u00e9,\u00ea",
        "\u00ed",
        null,
        null,
        "\u00e7",
        null,
        null,
        "\u00e4,\u00e5,\u00e6,\u00aa",
        "\u00f2,\u00f6,\u0153,\u00f8,\u014d,\u00ba",
        "\u00f9,\u00fb,\u016b",
        "\u00e8,\u0119,\u0117,\u0113,\u00eb",
        null,
        null,
        "\u00ee,\u00ec,\u00ef,\u012f,\u012b",
        null,
        "\u010d,\u0107",
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        "\u00e7"
    };

    private static final String[] TEXTS_rm = {
        "rm",
        null,
        null,
        "\u00f2,\u00f3,\u00f6,\u00f4,\u00f5,\u0153,\u00f8"
    };

    private static final String[] TEXTS_ro = {
        "ro",
        null,
        "\u0103,\u00e2",
        null,
        null,
        null,
        "\u00ee",
        "!text/double_9qm_rqm",
        "!text/single_9qm_rqm",
        null,
        null,
        "\u0219",
        "\u00e3,\u00e0,\u00e1,\u00e4,\u00e6,\u00e5,\u0101",
        null,
        null,
        null,
        null,
        null,
        "\u00ef,\u00ec,\u00ed,\u012f,\u012b",
        "\u00df,\u015b,\u0161",
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        "\u021b"
    };

    private static final String[] TEXTS_ru = {
        "ru",
        "\u0410\u0411\u0412",
        null,
        null,
        null,
        null,
        null,
        "!text/double_9qm_lqm",
        "!text/single_9qm_lqm",
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        "\u0451",
        null,
        null,
        null,
        null,
        "\u044a",
        null,
        null,
        null,
        null,
        "\u0449",
        "\u044b",
        "\u044d",
        "\u0438"
    };

    private static final String[] TEXTS_si = {
        "si",
        "\u0d85,\u0d86",
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        "\u0dbb\u0dd4"
    };

    private static final String[] TEXTS_sk = {
        "sk",
        null,
        "\u00e1,\u00e4",
        "\u00f4,\u00f3",
        "\u00fa",
        "\u00e9",
        "\u00ed",
        "!text/double_9qm_lqm",
        "!text/single_9qm_lqm",
        "\u010d",
        null,
        "\u0161",
        "\u0101,\u00e0,\u00e2,\u00e3,\u00e5,\u00e6,\u0105",
        "\u00f6,\u00f2,\u00f5,\u0153,\u0151,\u00f8",
        "\u016f,\u00fc,\u016b,\u0173,\u00f9,\u00fb,\u0171",
        "\u011b,\u0113,\u0117,\u00e8,\u00ea,\u00eb,\u0119",
        "\u0148",
        "\u017e",
        "\u012b,\u012f,\u00ec,\u00ee,\u00ef,\u0131",
        "\u00df,\u015b,\u015f",
        "\u00e7,\u0107",
        "!text/single_raqm_laqm",
        "!text/double_raqm_laqm",
        "\u00fd",
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        "\u010f",
        null,
        "\u017c,\u017a",
        null,
        null,
        null,
        "\u0165",
        "\u0146,\u00f1,\u0144",
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        "\u013e,\u013a",
        "\u0155",
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        "\u00ff",
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        "\u013c,\u0142",
        "\u0159,\u0157",
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        "\u0163"
    };

    private static final String[] TEXTS_sl = {
        "sl",
        null,
        null,
        null,
        null,
        null,
        null,
        "!text/double_9qm_lqm",
        "!text/single_9qm_lqm",
        "\u010d",
        null,
        "\u0161",
        null,
        null,
        null,
        null,
        null,
        "\u017e",
        null,
        null,
        "\u0107",
        "!text/single_raqm_laqm",
        "!text/double_raqm_laqm"
    };

    private static final String[] TEXTS_sr = {
        "sr",
        "\u0410\u0411\u0412",
        null,
        null,
        null,
        null,
        null,
        "!text/double_9qm_lqm",
        "!text/single_9qm_lqm",
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        "!text/single_raqm_laqm",
        "!text/double_raqm_laqm",
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        "\u0450",
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        "\u045d",
        null,
        "\u0437",
        "\u045b",
        "\u0455",
        "\u0452"
    };

    private static final String[] TEXTS_sr_ZZ = {
        "sr_ZZ",
        null,
        null,
        null,
        null,
        "\u00e8",
        "\u00ec",
        null,
        null,
        "\u010d,\u0107,%",
        null,
        "\u0161,%",
        null,
        null,
        null,
        null,
        null,
        "\u017e,%",
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        "\u0111,%",
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        "Idi",
        "\u0160alji",
        "Sled",
        "Gotov",
        "Tra\u017ei",
        "Preth",
        "Pauza",
        "\u010cekaj"
    };

    private static final String[] TEXTS_sv = {
        "sv",
        null,
        "\u00e4,\u00e5",
        "\u00f6",
        null,
        "\u00e9",
        null,
        null,
        null,
        null,
        null,
        null,
        "\u00e6,\u00e1,\u00e0,\u00e2,\u0105,\u00e3",
        "\u00f8,\u0153,\u00f3,\u00f2,\u00f4,\u00f5,\u014d",
        null,
        "\u00e8,\u00ea,\u00eb,\u0119",
        null,
        null,
        null,
        null,
        null,
        "!text/single_raqm_laqm",
        "!text/double_raqm_laqm",
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        "\u00f8,\u0153",
        null,
        null,
        "\u00e5",
        "\u00f6",
        "\u00e4",
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        "\u00e6"
    };

    private static final String[] TEXTS_sw = {
        "sw",
        null,
        "\u00e0,\u00e1,\u00e2,\u00e4,\u00e6,\u00e3,\u00e5,\u0101",
        "\u00f4,\u00f6,\u00f2,\u00f3,\u0153,\u00f8,\u014d,\u00f5",
        "\u00fb,\u00fc,\u00f9,\u00fa,\u016b",
        "\u00e8,\u00e9,\u00ea,\u00eb,\u0113",
        "\u00ee,\u00ef,\u00ed,\u012b,\u00ec",
        null,
        null,
        "\u00e7",
        null,
        "\u00df",
        null,
        null,
        null,
        null,
        "\u00f1",
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        "g\\'"
    };

    private static final String[] TEXTS_ta_IN = {
        "ta_IN",
        "\u0ba4\u0bae\u0bbf\u0bb4\u0bcd",
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        "\u0bf9"
    };

    private static final String[] TEXTS_ta_LK = {
        "ta_LK",
        "\u0ba4\u0bae\u0bbf\u0bb4\u0bcd",
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        "\u0dbb\u0dd4"
    };

    private static final String[] TEXTS_ta_SG = {
        "ta_SG",
        "\u0ba4\u0bae\u0bbf\u0bb4\u0bcd"
    };

    private static final String[] TEXTS_te = {
        "te",
        "\u0c05\u0c06\u0c07",
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        "\u20b9"
    };

    private static final String[] TEXTS_th = {
        "th",
        "\u0e01\u0e02\u0e04",
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        "\u0e3f"
    };

    private static final String[] TEXTS_tl = {
        "tl",
        null,
        "\u00e1,\u00e0,\u00e4,\u00e2,\u00e3,\u00e5,\u0105,\u00e6,\u0101,\u00aa",
        "\u00f3,\u00f2,\u00f6,\u00f4,\u00f5,\u00f8,\u0153,\u014d,\u00ba",
        "\u00fa,\u00fc,\u00f9,\u00fb,\u016b",
        "\u00e9,\u00e8,\u00eb,\u00ea,\u0119,\u0117,\u0113",
        "\u00ed,\u00ef,\u00ec,\u00ee,\u012f,\u012b",
        null,
        null,
        "\u00e7,\u0107,\u010d",
        null,
        null,
        null,
        null,
        null,
        null,
        "\u00f1,\u0144"
    };

    private static final String[] TEXTS_tr = {
        "tr",
        null,
        null,
        "\u00f6",
        "\u00fc",
        null,
        "\u0131",
        null,
        null,
        "\u00e7",
        null,
        "\u015f",
        null,
        "\u00f4,\u0153,\u00f2,\u00f3,\u00f5,\u00f8,\u014d",
        "\u00fb,\u00f9,\u00fa,\u016b",
        null,
        null,
        null,
        "\u00ee,\u00ef,\u00ec,\u00ed,\u012f,\u012b",
        "\u00df,\u015b,\u0161",
        "\u0107,\u010d",
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        "\u011f"
    };

    private static final String[] TEXTS_uk = {
        "uk",
        "\u0410\u0411\u0412",
        null,
        null,
        null,
        null,
        null,
        "!text/double_9qm_lqm",
        "!text/single_9qm_lqm",
        null,
        "\u20b4",
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        "\u044a",
        null,
        null,
        null,
        null,
        "\u0449",
        "\u0456",
        "\u0454",
        "\u0438",
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        "\u0457",
        null,
        null,
        "\u0491"
    };

    private static final String[] TEXTS_uz = {
        "uz",
        null,
        "\u00e2,\u00e4,\u00e1",
        "\u00f6,\u00f4,\u0153,\u00f2,\u00f3,\u00f5,\u00f8,\u014d",
        "\u00fc,\u00fb,\u00f9,\u00fa,\u016b",
        "\u0259,\u00e9",
        "\u0131,\u00ee,\u00ef,\u00ec,\u00ed,\u012f,\u012b",
        null,
        null,
        "\u00e7,\u0107,\u010d",
        null,
        "\u015f,\u00df,\u015b,\u0161",
        null,
        null,
        null,
        null,
        "\u0148,\u00f1",
        "\u017e",
        null,
        null,
        null,
        null,
        null,
        "\u00fd",
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        "\u011f"
    };

    private static final String[] TEXTS_vi = {
        "vi",
        null,
        "\u00e0,\u00e1,\u1ea3,\u00e3,\u1ea1,\u0103,\u1eb1,\u1eaf,\u1eb3,\u1eb5,\u1eb7,\u00e2,\u1ea7,\u1ea5,\u1ea9,\u1eab,\u1ead",
        "\u00f2,\u00f3,\u1ecf,\u00f5,\u1ecd,\u00f4,\u1ed3,\u1ed1,\u1ed5,\u1ed7,\u1ed9,\u01a1,\u1edd,\u1edb,\u1edf,\u1ee1,\u1ee3",
        "\u00f9,\u00fa,\u1ee7,\u0169,\u1ee5,\u01b0,\u1eeb,\u1ee9,\u1eed,\u1eef,\u1ef1",
        "\u00e8,\u00e9,\u1ebb,\u1ebd,\u1eb9,\u00ea,\u1ec1,\u1ebf,\u1ec3,\u1ec5,\u1ec7",
        "\u00ec,\u00ed,\u1ec9,\u0129,\u1ecb",
        null,
        null,
        null,
        "\u20ab",
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        "\u1ef3,\u00fd,\u1ef7,\u1ef9,\u1ef5",
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        "\u0111"
    };

    private static final String[] TEXTS_zu = {
        "zu",
        null,
        "\u00e0,\u00e1,\u00e2,\u00e4,\u00e6,\u00e3,\u00e5,\u0101",
        "\u00f3,\u00f4,\u00f6,\u00f2,\u0153,\u00f8,\u014d,\u00f5",
        "\u00fa,\u00fb,\u00fc,\u00f9,\u016b",
        "\u00e9,\u00e8,\u00ea,\u00eb,\u0113",
        "\u00ed,\u00ee,\u00ef,\u012b,\u00ec",
        null,
        null,
        "\u00e7",
        null,
        "\u00df",
        null,
        null,
        null,
        null,
        "\u00f1"
    };

    private static final String[] TEXTS_zz = {
        "zz",
        null,
        "\u00e0,\u00e1,\u00e2,\u00e3,\u00e4,\u00e5,\u00e6,\u0101,\u0103,\u0105,\u00aa",
        "\u00f2,\u00f3,\u00f4,\u00f5,\u00f6,\u00f8,\u014d,\u014f,\u0151,\u0153,\u00ba",
        "\u00f9,\u00fa,\u00fb,\u00fc,\u0169,\u016b,\u016d,\u016f,\u0171,\u0173",
        "\u00e8,\u00e9,\u00ea,\u00eb,\u0113,\u0115,\u0117,\u0119,\u011b",
        "\u00ec,\u00ed,\u00ee,\u00ef,\u0129,\u012b,\u012d,\u012f,\u0131,\u0133",
        null,
        null,
        "\u00e7,\u0107,\u0109,\u010b,\u010d",
        null,
        "\u00df,\u015b,\u015d,\u015f,\u0161,\u017f",
        null,
        null,
        null,
        null,
        "\u00f1,\u0144,\u0146,\u0148,\u0149,\u014b",
        "\u017a,\u017c,\u017e",
        null,
        null,
        null,
        null,
        null,
        "\u00fd,\u0177,\u00ff,\u0133",
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        "\u010f,\u0111,\u00f0",
        "\u011d,\u011f,\u0121,\u0123",
        null,
        null,
        null,
        null,
        "\u00fe,\u0163,\u0165,\u0167",
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        "\u013a,\u013c,\u013e,\u0140,\u0142",
        "\u0155,\u0157,\u0159",
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        "\u0125",
        "\u0135",
        "\u0137,\u0138",
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        "\u0175"
    };


    private static final Object[] LOCALES_AND_TEXTS = {
    // "locale", TEXT_ARRAY,  /* numberOfNonNullText/lengthOf_TEXT_ARRAY localeName */
        "DEFAULT", TEXTS_DEFAULT,
        "af", TEXTS_af,
        "ar", TEXTS_ar,
        "az", TEXTS_az,
        "be", TEXTS_be,
        "bg", TEXTS_bg,
        "bn_BD", TEXTS_bn_BD,
        "bn_IN", TEXTS_bn_IN,
        "ca", TEXTS_ca,
        "ckb", TEXTS_ckb,
        "cs", TEXTS_cs,
        "da", TEXTS_da,
        "de", TEXTS_de,
        "el", TEXTS_el,
        "en", TEXTS_en,
        "eo", TEXTS_eo,
        "es", TEXTS_es,
        "et", TEXTS_et,
        "eu", TEXTS_eu,
        "fa", TEXTS_fa,
        "fi", TEXTS_fi,
        "fr", TEXTS_fr,
        "gl", TEXTS_gl,
        "hi", TEXTS_hi,
        "hi_ZZ", TEXTS_hi_ZZ,
        "hr", TEXTS_hr,
        "hu", TEXTS_hu,
        "hy", TEXTS_hy,
        "is", TEXTS_is,
        "it", TEXTS_it,
        "iw", TEXTS_iw,
        "ka", TEXTS_ka,
        "kk", TEXTS_kk,
        "km", TEXTS_km,
        "kn", TEXTS_kn,
        "ky", TEXTS_ky,
        "lo", TEXTS_lo,
        "lt", TEXTS_lt,
        "lv", TEXTS_lv,
        "mk", TEXTS_mk,
        "ml", TEXTS_ml,
        "mn", TEXTS_mn,
        "mr", TEXTS_mr,
        "my", TEXTS_my,
        "nb", TEXTS_nb,
        "ne", TEXTS_ne,
        "nl", TEXTS_nl,
        "pl", TEXTS_pl,
        "pt", TEXTS_pt,
        "rm", TEXTS_rm,
        "ro", TEXTS_ro,
        "ru", TEXTS_ru,
        "si", TEXTS_si,
        "sk", TEXTS_sk,
        "sl", TEXTS_sl,
        "sr", TEXTS_sr,
        "sr_ZZ", TEXTS_sr_ZZ,
        "sv", TEXTS_sv,
        "sw", TEXTS_sw,
        "ta_IN", TEXTS_ta_IN,
        "ta_LK", TEXTS_ta_LK,
        "ta_SG", TEXTS_ta_SG,
        "te", TEXTS_te,
        "th", TEXTS_th,
        "tl", TEXTS_tl,
        "tr", TEXTS_tr,
        "uk", TEXTS_uk,
        "uz", TEXTS_uz,
        "vi", TEXTS_vi,
        "zu", TEXTS_zu,
        "zz", TEXTS_zz
    };

    static {
        for (int index = 0; index < NAMES.length; index++) {
            sNameToIndexesMap.put(NAMES[index], index);
        }

        for (int i = 0; i < LOCALES_AND_TEXTS.length; i += 2) {
            final String locale = (String)LOCALES_AND_TEXTS[i];
            final String[] textsTable = (String[])LOCALES_AND_TEXTS[i + 1];
            sLocaleToTextsTableMap.put(locale, textsTable);
            sTextsTableToLocaleMap.put(textsTable, locale);
        }
    }
}
